# -*- coding: utf-8 -*-
import datetime

from django.utils.translation import ugettext_lazy as _
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.core.admin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):

    def __init__(self, **kwargs):
        kwargs = {
            'title': "Organization",
            'display': "tabs",
            'children': [OrganizationModels(), OrganizationOtherModels()]
        }
        super(DefaultDashboard, self).__init__(**kwargs)


class OrganizationDashboard(modules.Group):

    def __init__(self, **kwargs):
        kwargs = {
            'title': "Organization",
            'display': "tabs",
            'children': [OrganizationModels(), OrganizationOtherModels()]
        }
        super(OrganizationDashboard, self).__init__(**kwargs)


class Models(modules.ModelList):

    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Main Models"),
            'models': ('jmb.organization.models.*',),
        }
        super(Models, self).__init__(**kwargs)


class OrganizationModels(modules.ModelList):

    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Models"),
            'models': (
                'jmb.organization.models.Organization',
                'jmb.organization.models.Contact'
            ),
        }
        super(OrganizationModels, self).__init__(**kwargs)


class OrganizationOtherModels(modules.ModelList):

    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Others"),
            'models': ('jmb.organization.models.*',),
            'exclude': (
                'jmb.organization.models.Organization',
                'jmb.organization.models.Contact',
            ),
        }
        super(OrganizationOtherModels, self).__init__(**kwargs)


class DefaultAppDashboard(AppIndexDashboard):

    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        request = context['request']
        self.children.append(
            DefaultDashboard(),
        )
# Used in /admin
jmb_dashboard.register_group(OrganizationDashboard, 'jmb.organization')
# Used in /admin/Organization
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.organization')
