#! -*- coding: utf-8 -*-
"""
Helper module for jmb.organization app
"""
import re
import datetime

from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User
from django.contrib.auth.tokens import default_token_generator
from django.template.loader import get_template, render_to_string
from django.template import Context
from django.core.mail import EmailMultiAlternatives
from django.template.loader import get_template, render_to_string
from django.contrib.sites.models import get_current_site
from django.utils.http import int_to_base36, base36_to_int
from django.http import HttpResponseRedirect
from django.forms.models import construct_instance

from jmb.core.utils.cmsutils import get_abs_url_from_slug


def send_registration_email(user, cms_model_instance, request, page_relative_url=None):
    """
    send email for successful registration
    """

    token_generator = default_token_generator
    html_template = get_template(cms_model_instance.email_registration_done_template)
    text_template = cms_model_instance.email_registration_done_template.split('.')[0]+'.txt'
    current_site = get_current_site(request)
    site_name = current_site.name
    uid = int_to_base36(user.id)
    token = token_generator.make_token(user)
    protocol = "https" if request.is_secure() else "http"
    domain = current_site.domain

    if page_relative_url:
        activate_url = "%s://%s%s?uidb36=%s&token=%s&activate_reg=1" % (
            protocol,
            str(request.get_host()),
            str(request.get_full_path()),
            str(uid),
            str(token)
        )
    else:
        activate_url = "%s?uidb36=%s&token=%s&activate_reg=1" % (
            request.build_absolute_uri(),
            str(uid),
            str(token)
        )
    ctx_dict = Context({
        'email': user.email,
        'domain': domain,
        'site_name': site_name,
        'user': user,
        'sent_from': cms_model_instance.sent_from,
        'activate_url': activate_url,
        'static': '%s://%s%s' % (protocol, str(request.get_host()), settings.STATIC_URL),
        #'static': protocol+"://"+get_acomea_host()+settings.STATIC_URL,
        'homepage': '%s://%s' % (protocol, str(request.get_host()))
    })

    subject = "Richiesta Registrazione %s " % ctx_dict['site_name']
    from_email = cms_model_instance.sent_from
    to = [user.email]

    text_message = render_to_string(text_template, ctx_dict)
    html_message = html_template.render(ctx_dict)
    msg = EmailMultiAlternatives(subject, text_message, from_email, to)
    msg.attach_alternative(html_message, "text/html")
    msg.send()
# except Exception, e:
#     log.debug("%s" % e)


def send_activation_email(user, cms_model_instance, request, page_relative_url=None):
    """
    send email for successful user activation
    """
    if user.email:
        html_template = get_template(cms_model_instance.email_activation_done_template)
        text_template = cms_model_instance.email_activation_done_template.split('.')[0]+'.txt'
        current_site = get_current_site(request)
        site_name = current_site.name
        if not page_relative_url:
            page_relative_url = request.path
        protocol = "https" if request.is_secure() else "http"
        domain = current_site.domain

        ctx_dict = Context({
            #'email': profilo.user.email,
            #'domain': domain,
            'site_name': site_name,
            'user': user,
            'sent_from': cms_model_instance.sent_from,
            'static': '%s://%s%s' % (protocol, str(request.get_host()), settings.STATIC_URL),
            'homepage': '%s://%s' % (protocol, str(request.get_host()))
        })

        subject = "Attivazione utente %s " % ctx_dict['site_name']
        from_email = cms_model_instance.sent_from
        to = [user.email]
        #try:
        #    # debug setting: to define in local settings: send email to this address
        #    # instead of real user address
        #    to=[settings.ACOMEA_PROFILO_LOCAL_RICHIEDIREG_EMAIL_SENT_TO]
        #except AttributeError:
        #    pass

        text_message = render_to_string(text_template, ctx_dict)
        html_message = html_template.render(ctx_dict)
        msg = EmailMultiAlternatives(subject, text_message, from_email, to)
        msg.attach_alternative(html_message, "text/html")
        msg.send()

def send_recovery_password_email(user, cms_model_instance, request, page_relative_url=None):
    """
    send recovery password email to user email address
    """

    current_site = get_current_site(request)
    site_name = current_site.name
    domain = current_site.domain
    if not page_relative_url:
        page_relative_url = request.get_full_path()
    protocol = "https" if request.is_secure() else "http"
    host = request.get_host()
    ctx_dict = Context({
        'email': user.email,
        'domain': domain,
        'site_name': site_name,
        'uid': int_to_base36(user.id),
        'user': user,
        'token': default_token_generator.make_token(user),
        'protocol': protocol,
        'page_relative_url': page_relative_url,
        'host': host,
        'static': '%s://%s%s' % (protocol, host, settings.STATIC_URL),
        'homepage': '%s://%s' % (protocol, host)

    })
    html_template = get_template(cms_model_instance.email_template_name)
    text_template = cms_model_instance.email_template_name.split('.')[0]+'.txt'
    subject = "Richiesta recupero password %s " % ctx_dict['site_name']
    from_email = cms_model_instance.sent_from
    to = [user.email]
    #try:
    #    # debug setting: to define in local settings: send the recovery link to specified
    #    # address instead of real user address
    #    to=[settings.ACOMEA_UTENTI_LOCAL_RECOVERYPW_EMAIL_SENT_TO]
    #except AttributeError:
    #    pass

    text_message = render_to_string(text_template, ctx_dict)
    html_message = html_template.render(ctx_dict)
    msg = EmailMultiAlternatives(subject, text_message, from_email, to)
    msg.attach_alternative(html_message, "text/html")
    msg.send()

def send_reset_password_email(user, cms_model_instance, request, page_relative_url=None):
    """
     send reset password email to user email address
    """
    current_site = get_current_site(request)
    site_name = current_site.name
    domain = current_site.domain
    if not page_relative_url:
        page_relative_url = request.get_full_path()
    protocol = "https" if request.is_secure() else "http"
    host = request.get_host()
    ctx_dict = Context({
        'email': user.email,
        'domain': domain,
        'site_name': site_name,
        'user': user,
        'page_relative_url': page_relative_url,
        'static': '%s://%s%s' % (protocol, host, settings.STATIC_URL),
        'homepage': '%s://%s' % (protocol, host)

    })
    html_template = get_template(cms_model_instance.email_template_name)
    text_template = cms_model_instance.email_template_name.split('.')[0]+'.txt'
    subject = "Modifica password %s " % ctx_dict['site_name']
    from_email = cms_model_instance.sent_from
    to = [user.email]
    #try:
    #    # debug setting: to define in local settings: send the recovery link to specified
    #    # address instead of real user address
    #    to=[settings.ACOMEA_UTENTI_LOCAL_RECOVERYPW_EMAIL_SENT_TO]
    #except AttributeError:
    #    pass

    text_message = render_to_string(text_template, ctx_dict)
    html_message = html_template.render(ctx_dict)
    msg = EmailMultiAlternatives(subject, text_message, from_email, to)
    msg.attach_alternative(html_message, "text/html")
    msg.send()


def check_activation_url(request):
    """
    check request parameters to activate a user after registration. If token is valid, activate _user
    and return it
    """
    if (
        'uidb36' in request.GET and
        'token' in request.GET and
        'activate_reg' in request.GET and
        request.GET['activate_reg'] == '1'
    ):
        try:
            uid_int = base36_to_int(request.GET['uidb36'])
            _user = User.objects.get(id=uid_int)
            if default_token_generator.check_token(_user, request.GET['token']):
                _user.is_active = True
                _user.save()
                return _user
            else:
                return False
        except (ValueError, User.DoesNotExist) as exc:
            # error / user doesn't exists
            return False


def check_reset_password_url(request):
    """
    check request parameters to reset password for a non logged-in user:
    - check if user exists
    - check the token
    If valid, return True; else return False
    """
    if (
        'uidb36' in request.GET and
        'token' in request.GET and
        'reset_pw' in request.GET and
        request.GET['reset_pw'] == '1'
    ):
        try:
            uid_int = base36_to_int(request.GET['uidb36'])
            _user = User.objects.get(id=uid_int)
        except (ValueError, User.DoesNotExist):
            return (False, None)
        if _user is not None and default_token_generator.check_token(_user, request.GET['token']):
            # l'utente esiste e il token è valido
            return (True, _user)

    return (False, None)
def check_password_strenght(password):
    """
    check password strenghtness
    """
    strength = ['Blank', 'Very Weak', 'Weak', 'Medium', 'Strong', 'Very Strong']
    score = 0

    if len(password) < 1:
        return score, strength[0]
    if len(password) < 4:
        return score, strength[1]

    if len(password) >= 8:
        score = score + 1
    if len(password) >= 11:
        score = score + 1

    if re.search('\d+', password):
        score = score + 1
    if re.search('[a-z]', password) and re.search('[A-Z]', password):
        score = score + 1
    if re.search('.[!,@,#,$,%,^,&,*,?,_,~,-,£,(,)]', password):
        score = score + 1
    return score, strength[score]
